package cn.hnthyy.thmz.service.impl.his.mz;

import cn.hnthyy.thmz.entity.his.mz.CodeNameEntity;
import cn.hnthyy.thmz.mapper.his.mz.MzZdCommonMapper;
import cn.hnthyy.thmz.service.his.mz.MzZdCommonService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
@Service
public class MzZdCommonServiceImpl implements MzZdCommonService {
    @SuppressWarnings("all")
    @Autowired
    private MzZdCommonMapper zdCommonMapper;
    @Override
    public List<CodeNameEntity> queryCountry() {
        return zdCommonMapper.selectCountry();
    }

    @Override
    public List<CodeNameEntity> queryNation() {
        return zdCommonMapper.selectNation();
    }

    @Override
    public List<CodeNameEntity> queryDiagnose() {
        return zdCommonMapper.selectDiagnose();
    }

    @Override
    public List<CodeNameEntity> queryDistrict() {
        return zdCommonMapper.selectDistrict();
    }

    @Override
    public List<CodeNameEntity> queryRelation() {
        return zdCommonMapper.selectRelation();
    }

    @Override
    public List<CodeNameEntity> queryOccupation() {
        return zdCommonMapper.selectOccupation();
    }

    @Override
    public List<CodeNameEntity> queryAdmissStatus() {
        return zdCommonMapper.selectAdmissStatus();
    }
}
